@@ -244,7 +244,7 @@ impl AdminInterfaceApi for RealAdminInterfaceApi {
                 let (app, errors) = self
                     .conductor_handle
                     .clone()
-                    .enable_app(&installed_app_id)
+                    .enable_app(installed_app_id.clone())
                     .await?;
 
                 let app_cells: HashSet<_> = app.required_cells().collect();
@@ -270,7 +270,7 @@ impl AdminInterfaceApi for RealAdminInterfaceApi {
                 // Disable app
                 self.conductor_handle
                     .clone()
-                    .disable_app(&installed_app_id, DisabledAppReason::User)
+                    .disable_app(installed_app_id, DisabledAppReason::User)
                     .await?;
                 Ok(AdminResponse::AppDisabled)
             }
@@ -279,7 +279,7 @@ impl AdminInterfaceApi for RealAdminInterfaceApi {
                 let app = self
                     .conductor_handle
                     .clone()
-                    .start_app(&installed_app_id)
+                    .start_app(installed_app_id)
                     .await?;
                 Ok(AdminResponse::AppStarted(app.status().is_running()))
             }
