@@ -49,6 +49,10 @@ use holochain_p2p::HolochainP2pCell;
 use holochain_p2p::*;
 use publish_dht_ops_consumer::*;
 
+mod countersigning_consumer;
+use countersigning_consumer::*;
+
+use super::workflow::countersigning_workflow::CountersigningWorkspace;
 use super::workflow::error::WorkflowError;
 
 /// Spawns several long-running tasks which are responsible for processing work
@@ -56,6 +60,7 @@ use super::workflow::error::WorkflowError;
 ///
 /// Waits for the initial loop to complete before returning, to prevent causing
 /// a race condition by trying to run a workflow too soon after cell creation.
+#[allow(clippy::too_many_arguments)]
 pub async fn spawn_queue_consumer_tasks(
     env: EnvWrite,
     cache: EnvWrite,
@@ -64,6 +69,7 @@ pub async fn spawn_queue_consumer_tasks(
     conductor_api: impl CellConductorApiT + 'static,
     task_sender: sync::mpsc::Sender<ManagedTaskAdd>,
     stop: sync::broadcast::Sender<()>,
+    countersigning_workspace: CountersigningWorkspace,
 ) -> (QueueTriggers, InitialQueueTriggers) {
     let cell_id = cell_network.cell_id();
     // Publish
@@ -98,16 +104,14 @@ pub async fn spawn_queue_consumer_tasks(
         .await
         .expect("Failed to manage workflow handle");
 
-    let (create_tx_sys, get_tx_sys) = tokio::sync::oneshot::channel();
-
     // Integration
     let (tx_integration, handle) = spawn_integrate_dht_ops_consumer(
         env.clone(),
         conductor_handle.clone(),
         cell_network.cell_id(),
         stop.subscribe(),
-        get_tx_sys,
         tx_receipt.clone(),
+        cell_network.clone(),
     );
     task_sender
         .send(ManagedTaskAdd::cell_critical(
@@ -155,12 +159,30 @@ pub async fn spawn_queue_consumer_tasks(
         ))
         .await
         .expect("Failed to manage workflow handle");
-    if create_tx_sys.send(tx_sys.clone()).is_err() {
-        panic!("Failed to send tx_sys");
-    }
+    let (tx_cs, handle) = spawn_countersigning_consumer(
+        env.clone(),
+        stop.subscribe(),
+        conductor_handle.clone(),
+        countersigning_workspace,
+        cell_network.clone(),
+        tx_sys.clone(),
+    );
+    task_sender
+        .send(ManagedTaskAdd::cell_critical(
+            handle,
+            cell_id.clone(),
+            "countersigning_consumer",
+        ))
+        .await
+        .expect("Failed to manage workflow handle");
 
     (
-        QueueTriggers::new(tx_sys.clone(), tx_publish.clone()),
+        QueueTriggers {
+            sys_validation: tx_sys.clone(),
+            publish_dht_ops: tx_publish.clone(),
+            countersigning: tx_cs,
+            integrate_dht_ops: tx_integration.clone(),
+        },
         InitialQueueTriggers::new(tx_sys, tx_publish, tx_app, tx_integration, tx_receipt),
     )
 }
@@ -172,6 +194,11 @@ pub struct QueueTriggers {
     pub sys_validation: TriggerSender,
     /// Notify the ProduceDhtOps workflow to run, i.e. after InvokeCallZome
     pub publish_dht_ops: TriggerSender,
+    /// Notify the countersigning workflow to run, i.e. after receiving
+    /// new countersigning data.
+    pub countersigning: TriggerSender,
+    /// Notify the IntegrateDhtOps workflow to run, i.e. after InvokeCallZome
+    pub integrate_dht_ops: TriggerSender,
 }
 
 /// The triggers to run once at the start of a cell
@@ -186,16 +213,6 @@ pub struct InitialQueueTriggers {
     validation_receipt: TriggerSender,
 }
 
-impl QueueTriggers {
-    /// Create a new queue trigger
-    pub fn new(sys_validation: TriggerSender, publish_dht_ops: TriggerSender) -> Self {
-        Self {
-            sys_validation,
-            publish_dht_ops,
-        }
-    }
-}
-
 impl InitialQueueTriggers {
     fn new(
         sys_validation: TriggerSender,
