@@ -1,40 +1,52 @@
 use crate::core::ribosome::CallContext;
 use crate::core::ribosome::HostFnAccess;
 use crate::core::ribosome::RibosomeT;
-use holochain_p2p::HolochainP2pCellT;
 use holochain_types::prelude::*;
 use holochain_wasmer_host::prelude::WasmError;
 use std::sync::Arc;
+use futures::future::join_all;
+use holochain_p2p::HolochainP2pCellT;
 
 pub fn call_remote(
     _ribosome: Arc<impl RibosomeT>,
     call_context: Arc<CallContext>,
-    input: CallRemote,
-) -> Result<ZomeCallResponse, WasmError> {
+    inputs: Vec<CallRemote>,
+) -> Result<Vec<ZomeCallResponse>, WasmError> {
     match HostFnAccess::from(&call_context.host_context()) {
         HostFnAccess {
             write_network: Permission::Allow,
             ..
         } => {
             // it is the network's responsibility to handle timeouts and return an Err result in that case
-            let result: Result<SerializedBytes, _> = tokio_helper::block_forever_on(async move {
-                let network = call_context.host_context().network().clone();
-                network
-                    .call_remote(
-                        input.target_agent_as_ref().to_owned(),
-                        input.zome_name_as_ref().to_owned(),
-                        input.fn_name_as_ref().to_owned(),
-                        input.cap_as_ref().to_owned(),
-                        input.payload_as_ref().to_owned(),
-                    )
-                    .await
+            let results: Vec<Result<SerializedBytes, _>> = tokio_helper::block_forever_on(async move {
+                join_all(inputs.into_iter().map(|input| {
+                    async {
+                        let CallRemote {
+                            target_agent,
+                            zome_name,
+                            fn_name,
+                            cap,
+                            payload,
+                        } = input;
+                        call_context.host_context().network().call_remote(
+                            target_agent,
+                            zome_name,
+                            fn_name,
+                            cap,
+                            payload,
+                        ).await
+                    }
+                })).await
             });
-            let result = match result {
-                Ok(r) => ZomeCallResponse::try_from(r)?,
-                Err(e) => ZomeCallResponse::NetworkError(e.to_string()),
-            };
+            let results: Result<Vec<_>, _> = results.into_iter().map(|result| match result {
+                Ok(r) => match ZomeCallResponse::try_from(r) {
+                    Ok(v) => Ok(v),
+                    Err(e) => Err(e),
+                },
+                Err(e) => Ok(ZomeCallResponse::NetworkError(e.to_string())),
+            }).collect();
 
-            Ok(result)
+            Ok(results?)
         }
         _ => unreachable!(),
     }
